/**
 * Copyright 2010 Trustees of the University of Pennsylvania Licensed under the
 * Educational Community License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License. You may
 * obtain a copy of the License at
 *
 * http://www.osedu.org/licenses/ECL-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an "AS IS"
 * BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */


package metridoc.impl.iterator;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.util.zip.GZIPInputStream;
import metridoc.iterator.CloseableIterator;
import metridoc.iterator.IteratorProvider;
import org.apache.camel.Exchange;
import org.apache.camel.component.file.GenericFile;

/**
 *
 * @author tbarker
 */
public class LineIteratorProvider implements IteratorProvider<String> {


    @Override
    public CloseableIterator<String> create(Exchange exchange) {
        GenericFile<File> genericFile = exchange.getIn().getBody(GenericFile.class);
        File file = exchange.getContext().getTypeConverter().convertTo(File.class, genericFile.getBody());
        String fileName = genericFile.getFileName();

        try {
            FileInputStream inputStream = new FileInputStream(file);
            if (fileName.endsWith(".gz")) {
                return new CloseableLineIterator(new GZIPInputStream(inputStream));
            }
            return new CloseableLineIterator(inputStream);
        } catch (IOException ex) {
            throw new RuntimeException("could not find the file", ex);
        }
    }
}
