/**
 * Copyright 2010 Trustees of the University of Pennsylvania Licensed under the
 * Educational Community License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License. You may
 * obtain a copy of the License at
 *
 * http://www.osedu.org/licenses/ECL-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an "AS IS"
 * BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package metridoc.launcher

import org.apache.camel.model.ChoiceDefinition
import org.apache.camel.model.ProcessorDefinition
import org.apache.camel.language.groovy.CamelGroovyMethods
import metridoc.launcher.ClosureProcessor
import metridoc.aggregator.InflightAggregationWrapper
import metridoc.aggregator.BodyAggregator

ProcessorDefinition.metaClass.filter = { filter ->
    if (filter instanceof Closure) {
        filter = CamelGroovyMethods.toExpression(filter)
    }
    delegate.filter(filter);
}

ChoiceDefinition.metaClass.when = { filter ->
    if (filter instanceof Closure) {
        filter = CamelGroovyMethods.toExpression(filter)
    }
    delegate.when(filter);
}

ProcessorDefinition.metaClass.process = {filter ->
    if (filter instanceof Closure) {
        filter = new ClosureProcessor(filter)
    }
    delegate.process(filter);
}

ProcessorDefinition.metaClass.aggregateBody = {
    delegate.aggregate(constant(true), new InflightAggregationWrapper(new BodyAggregator()))
                    completionSize(500).completionTimeout(2000);
}

ProcessorDefinition.metaClass.aggregateBody = {completionSize, completionTimeout=500 ->
    delegate.aggregate(constant(true), new InflightAggregationWrapper(new BodyAggregator()))
                    completionSize(completionSize).completionTimeout(completionTimeout);
}