/**
 * Copyright 2010 Trustees of the University of Pennsylvania Licensed under the
 * Educational Community License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License. You may
 * obtain a copy of the License at
 *
 * http://www.osedu.org/licenses/ECL-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an "AS IS"
 * BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package metridoc.polling;

import java.util.Set;
import metridoc.utils.CollectionUtils.Sets;
import org.apache.camel.Consumer;
import org.apache.camel.Endpoint;
import org.apache.camel.impl.DefaultPollingConsumerPollStrategy;

/**
 * a polling strategy that only allows one poll.  This can be used as a singleton since it uses object hashes on
 * a passed consumer and endpoint to determine if a poll has occured before.  This strategy can be used on file
 * polling camel consumers.
 *
 * @author tbarker
 */
public class OnePollOnlyStrategy extends DefaultPollingConsumerPollStrategy{

    private Set<Integer> pollOccurred = Sets.createHashSet();

    @Override
    public boolean begin(Consumer consumer, Endpoint endpoint) {

        int hashCode = (17 * 37) + System.identityHashCode(consumer);
        hashCode = (hashCode * 37) + System.identityHashCode(endpoint);

        boolean result = !pollOccurred.contains(hashCode);

        if (result) {
            pollOccurred.add(hashCode);
        }

        return result;
    }
}
